@@ -35,7 +35,8 @@ def expose_service(methods, public=False):
                                     error_message = 'Could not invoke token validation service'
                                     raise Exception
 
-                                request.META[proxy_server.HTTP_USER_TOKEN] = response[proxy_server.USER_TOKEN]
+                                response_json = json.loads(response.content)
+                                request.META[proxy_server.HTTP_USER_TOKEN] = response_json[proxy_server.USER_TOKEN]
                                 return api_view(methods)(view_func)(request, *args, **kwargs)
 
                             elif public is True and request.META.get(proxy_server.HTTP_USER_TOKEN) is None:
